import { ChangeDetectorRef, Component, EventEmitter, Input, OnInit, } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { Bu2Model, MyBu2Model } from 'src/app/shared/model/bu2.model';
import { Bu3Model, MyBu3Model } from 'src/app/shared/model/bu3.model';
import { Bu2Service } from 'src/app/shared/services/bu2.service';
import { Bu3Service } from 'src/app/shared/services/bu3.service';
import { FileService } from 'src/app/shared/services/file.service';
interface table {
  currentPage: number,
  page: number[],
  search: string
}
@Component({
  selector: 'app-section-registration',
  templateUrl: './section-registration.component.html',
  styleUrls: ['./section-registration.component.scss']
})
export class SectionRegistrationComponent implements OnInit {
  bu3List: Bu3Model[] = []
  bu3ListLoading = false
  bu3: Bu3Model = new MyBu3Model()
  bu3Table: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }

  selectedFile: File | null = null;
  selectedFileName: string = 'กรุณาเลือกไฟล์';

  bu3Modal: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }
  bu2List: Bu2Model[] = []
  bu2: Bu2Model = new MyBu2Model()
  bu2Modal: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }
  currentModal: 'add' | 'edit' | 'delete' = "add"
  constructor(private bu3Service: Bu3Service,
    private bu2Service: Bu2Service,
    private toastr: ToastrService,
    private cdr: ChangeDetectorRef,
    private fileService: FileService
  ) { }

  ngOnInit(): void {
    this.getBu3List()
    this.getBu2List()
  }

  onFileSelected(event: any) {
    this.selectedFile = event.target.files.length > 0 ? event.target.files[0] : null;
    this.selectedFileName = this.selectedFile?.name || "กรุณาเลือกไฟล์"
  }

  uploadFile() {
    if (!this.selectedFile) {
      alert('กรุณาเลือกไฟล์ก่อนอัปโหลด')
      return
    }
    const formData = new FormData();
    formData.append('file', this.selectedFile);
    this.bu3ListLoading = true
    this.fileService.upload(formData, 'mbu3').subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getBu3List()
        } else {
          this.showAlert(response.message, 'error')
          this.bu3ListLoading = false
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
        this.bu3ListLoading = false
      }
    })
  }

  downloadFile() {
    const fileName = 'IMPORT_BU.xlsx'
    this.fileService.download(fileName).subscribe({
      next: response => {
        const url = window.URL.createObjectURL(response);
        const a = document.createElement("a");
        a.href = url;
        a.download = fileName;
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
        window.URL.revokeObjectURL(url);
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })

  }

  getBu3List() {
    this.bu3ListLoading = true
    this.bu3Service.getList().subscribe({
      next: response => {
        this.bu3List = response
        this.bu3ListLoading = false
        this.onBu3TableSearchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.bu3ListLoading = false
        this.cdr.detectChanges()
      }
    })
  }
  onBu3TableSearchChange() {
    this.bu3Table.currentPage = 1
    this.bu3Table.page = Array.from({ length: Math.ceil(this.filterBu3Table().length / 10) }, (_, i) => i + 1);
  }
  filterBu3Table() {
    return this.bu3List.filter(x => x.bu3id.toLowerCase().includes(this.bu3Table.search.toLowerCase()) ||
      x.tdesc.toLowerCase().includes(this.bu3Table.search.toLowerCase()) ||
      x.edesc.toLowerCase().includes(this.bu3Table.search.toLowerCase()))
  }
  selectBu3(bu3?: Bu3Model) {
    this.bu3 = new MyBu3Model(bu3)
    this.selectBu2()
    if (this.bu3.parent) {
      this.bu2Service.getById(this.bu3.parent).subscribe(response => {
        this.bu2 = new MyBu2Model(response)
        this.cdr.detectChanges()
      })
    }
  }
  bu3idChange() {
    const bu3 = this.bu3List.find(x => x.bu3id == this.bu3.bu3id)
    this.selectBu3(bu3 || new MyBu3Model({ bu3id: this.bu3.bu3id }))
  }
  onBu3ModalSearchChange() {
    this.bu3Modal.currentPage = 1
    this.bu3Modal.page = Array.from({ length: Math.ceil(this.filterBu3Modal().length / 10) }, (_, i) => i + 1);
  }
  filterBu3Modal() {
    return this.bu3List.filter(x => x.bu3id.toLowerCase().includes(this.bu3Modal.search.toLowerCase()) ||
      x.tdesc.toLowerCase().includes(this.bu3Modal.search.toLowerCase()) ||
      x.edesc.toLowerCase().includes(this.bu3Modal.search.toLowerCase()))
  }
  addBu3() {
    this.bu3ListLoading = true
    this.bu3Service.post({ ...this.bu3, parent: this.bu2.bu2id }).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getBu3List()
        } else {
          this.showAlert(response.message, 'error')
          this.bu3ListLoading = false
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
        this.bu3ListLoading = false
      }
    })
  }
  deleteBu3() {
    this.bu3ListLoading = true
    this.bu3Service.delete(this.bu3).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getBu3List()
        } else {
          this.showAlert(response.message, 'error')
          this.bu3ListLoading = false
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
        this.bu3ListLoading = false
      }
    })
  }

  getBu2List() {
    this.bu2Service.getList().subscribe(response => {
      this.bu2List = response
      this.onBu2ModalSearchChange()
    })
  }
  onBu2ModalSearchChange() {
    this.bu2Modal.currentPage = 1
    this.bu2Modal.page = Array.from({ length: Math.ceil(this.filterBu2Modal().length / 10) }, (_, i) => i + 1);
  }
  bu2idChange() {
    const bu2 = this.bu2List.find(x => x.bu2id == this.bu2.bu2id)
    this.selectBu2(bu2 || new MyBu2Model({ bu2id: this.bu2.bu2id }))
  }
  filterBu2Modal() {
    return this.bu2List.filter(x => x.bu2id.toLowerCase().includes(this.bu2Modal.search.toLowerCase()) ||
      x.tdesc.toLowerCase().includes(this.bu2Modal.search.toLowerCase()) ||
      x.edesc.toLowerCase().includes(this.bu2Modal.search.toLowerCase()))
  }
  selectBu2(bu2?: Bu2Model) {
    this.bu2 = new MyBu2Model(bu2)
  }

  showAlert(text: string, type: 'success' | 'error') {
    this.toastr[type](text, 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    })
  }
}

