import { ChangeDetectorRef, Component, EventEmitter, Input, OnInit } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { Bu3Model, MyBu3Model } from 'src/app/shared/model/bu3.model';
import { Bu4Model, MyBu4Model } from 'src/app/shared/model/bu4.model';
import { Bu3Service } from 'src/app/shared/services/bu3.service';
import { Bu4Service } from 'src/app/shared/services/bu4.service';
import { FileService } from 'src/app/shared/services/file.service';
interface table {
  currentPage: number,
  page: number[],
  search: string
}
@Component({
  selector: 'app-sub-department-one',
  templateUrl: './sub-department-one.component.html',
  styleUrls: ['./sub-department-one.component.scss']
})
export class SubDepartmentOneComponent implements OnInit {
  bu4List: Bu4Model[] = []
  bu4ListLoading = false
  bu4: Bu4Model = new MyBu4Model()
  bu4Table: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }

  selectedFile: File | null = null;
  selectedFileName: string = 'กรุณาเลือกไฟล์';

  bu4Modal: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }
  bu3List: Bu3Model[] = []
  bu3: Bu3Model = new MyBu3Model()
  bu3Modal: table = {
    currentPage: 1,
    page: Array.from({ length: 1 }, (_, i) => i + 1),
    search: ""
  }
  currentModal: 'add' | 'edit' | 'delete' = "add"
  constructor(private bu4Service: Bu4Service,
    private bu3Service: Bu3Service,
    private toastr: ToastrService,
    private cdr: ChangeDetectorRef,
    private fileService: FileService
  ) { }

  ngOnInit(): void {
    this.getBu4List()
    this.getBu3List()
  }

  onFileSelected(event: any) {
    this.selectedFile = event.target.files.length > 0 ? event.target.files[0] : null;
    this.selectedFileName = this.selectedFile?.name || "กรุณาเลือกไฟล์"
  }

  uploadFile() {
    if (!this.selectedFile) {
      alert('กรุณาเลือกไฟล์ก่อนอัปโหลด')
      return
    }
    const formData = new FormData();
    formData.append('file', this.selectedFile);
    this.bu4ListLoading = true
    this.fileService.upload(formData, 'mbu4').subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getBu4List()
        } else {
          this.showAlert(response.message, 'error')
          this.bu4ListLoading = false
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
        this.bu4ListLoading = false
      }
    })
  }

  downloadFile() {
    const fileName = 'IMPORT_BU.xlsx'
    this.fileService.download(fileName).subscribe({
      next: response => {
        const url = window.URL.createObjectURL(response);
        const a = document.createElement("a");
        a.href = url;
        a.download = fileName;
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
        window.URL.revokeObjectURL(url);
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })

  }
  getBu4List() {
    this.bu4ListLoading = true
    this.bu4Service.getList().subscribe({
      next: response => {
        this.bu4List = response
        this.bu4ListLoading = false
        this.onBu4TableSearchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.bu4ListLoading = false
        this.cdr.detectChanges()
      }
    })
  }
  onBu4TableSearchChange() {
    this.bu4Table.currentPage = 1
    this.bu4Table.page = Array.from({ length: Math.ceil(this.filterBu4Table().length / 10) }, (_, i) => i + 1);
  }
  filterBu4Table() {
    return this.bu4List.filter(x => x.bu4id.toLowerCase().includes(this.bu4Table.search.toLowerCase()) ||
      x.tdesc.toLowerCase().includes(this.bu4Table.search.toLowerCase()) ||
      x.edesc.toLowerCase().includes(this.bu4Table.search.toLowerCase()))
  }
  selectBu4(bu4?: Bu4Model) {
    this.bu4 = new MyBu4Model(bu4 || {})
    this.selectBu3()
    if (this.bu4.parent) {
      this.bu3Service.getById(this.bu4.parent).subscribe(response => {
        this.bu3 = new MyBu3Model(response)
        this.cdr.detectChanges()
      })
    }
  }
  bu4idChange() {
    const bu4 = this.bu4List.find(x => x.bu4id == this.bu4.bu4id)
    this.selectBu4(bu4 || new MyBu4Model({ bu4id: this.bu4.bu4id }))
  }
  onBu4ModalSearchChange() {
    this.bu4Modal.currentPage = 1
    this.bu4Modal.page = Array.from({ length: Math.ceil(this.filterBu4Modal().length / 10) }, (_, i) => i + 1);
  }
  filterBu4Modal() {
    return this.bu4List.filter(x => x.bu4id.toLowerCase().includes(this.bu4Modal.search.toLowerCase()) ||
      x.tdesc.toLowerCase().includes(this.bu4Modal.search.toLowerCase()) ||
      x.edesc.toLowerCase().includes(this.bu4Modal.search.toLowerCase()))
  }
  addBu4() {
    this.bu4ListLoading = true
    this.bu4Service.post({ ...this.bu4, parent: this.bu3.bu3id }).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getBu4List()
        } else {
          this.showAlert(response.message, 'error')
          this.bu4ListLoading = false
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
        this.bu4ListLoading = false
      }
    })
  }
  deleteBu4() {
    this.bu4ListLoading = true
    this.bu4Service.delete(this.bu4).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getBu4List()
        } else {
          this.showAlert(response.message, 'error')
          this.bu4ListLoading = false
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
        this.bu4ListLoading = false
      }
    })
  }

  getBu3List() {
    this.bu3Service.getList().subscribe(response => {
      this.bu3List = response
      this.onBu3ModalSearchChange()
    })
  }
  onBu3ModalSearchChange() {
    this.bu3Modal.currentPage = 1
    this.bu3Modal.page = Array.from({ length: Math.ceil(this.filterBu3Modal().length / 10) }, (_, i) => i + 1);
  }
  bu3idChange() {
    const bu3 = this.bu3List.find(x => x.bu3id == this.bu3.bu3id)
    this.selectBu3(bu3 || new MyBu3Model({ bu3id: this.bu3.bu3id }))
  }
  filterBu3Modal() {
    return this.bu3List.filter(x => x.bu3id.toLowerCase().includes(this.bu3Modal.search.toLowerCase()) ||
      x.tdesc.toLowerCase().includes(this.bu3Modal.search.toLowerCase()) ||
      x.edesc.toLowerCase().includes(this.bu3Modal.search.toLowerCase()))
  }
  selectBu3(bu3?: Bu3Model) {
    this.bu3 = new MyBu3Model(bu3 || {})
  }

  showAlert(text: string, type: 'success' | 'error') {
    this.toastr[type](text, 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    })
  }
}


