import { ChangeDetectorRef, Component } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { CompanyModel, MyCompanyModel } from 'src/app/shared/model/company.model';
import { CompanyService } from 'src/app/shared/services/company.service';
export interface DataModel {
  code: string
  tdesc: string
  edesc: string
  address: string
  contact: string
}
@Component({
  selector: 'app-company-registration-page',
  templateUrl: './company-registration-page.component.html',
  styleUrls: ['./company-registration-page.component.scss']
})
export class CompanyRegistrationPageComponent {
  currentPage = 1
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  search = ""
  modalStatus = 'add'
  dataList: { check: boolean, data: DataModel }[] = []
  dataLoading = false
  dataSelect: DataModel = { code: "", tdesc: "", edesc: "", address: "", contact: "" }

  constructor(private toastr: ToastrService,
    private companyService: CompanyService,
    private cdr: ChangeDetectorRef
  ) {
  }
  ngOnInit(): void {
    this.getCompanyList()
  }

  getCompanyList() {
    this.dataLoading = true
    this.companyService.getList().subscribe({
      next: response => {
        this.dataList = response.map(x => ({ check: false, data: { code: x.companyId, tdesc: x.tdesc, edesc: x.edesc, address: x.addressText, contact: x.descOther } }))
        this.dataLoading = false
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.dataLoading = false
        this.cdr.detectChanges()
      }
    })
  }

  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.dataListFilter().length / 10) }, (_, i) => i + 1);
  }
  dataListFilter() {
    return this.dataList.filter(x => {
      const data = x.data
      const match = data.code.includes(this.search) || data.tdesc.includes(this.search) || data.edesc.includes(this.search);
      return match;
    });
  }
  setData(data?: DataModel) {
    this.dataSelect = JSON.parse(JSON.stringify(data || { code: "", tdesc: "", edesc: "", address: "", contact: "" }));
  }

  addCompany() {
    const body = new MyCompanyModel({ companyId: this.dataSelect.code, tdesc: this.dataSelect.tdesc, edesc: this.dataSelect.edesc, addressText: this.dataSelect.address, descOther: this.dataSelect.contact })
    this.companyService.post(body).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getCompanyList()
        } else {
          this.showAlert(response.message, 'error')
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })
  }
  deleteCompany() {
    let body: CompanyModel | CompanyModel[] = []
    if (this.dataSelect.code) {
      body = new MyCompanyModel({ companyId: this.dataSelect.code, tdesc: this.dataSelect.tdesc, edesc: this.dataSelect.edesc, addressText: this.dataSelect.address, descOther: this.dataSelect.contact })
    } else {
      body = this.dataList.filter(x => x.check).map(x => new MyCompanyModel({ companyId: x.data.code, tdesc: x.data.tdesc, edesc: x.data.edesc, addressText: x.data.address, descOther: x.data.contact }))
    }
    this.companyService.delete(body).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getCompanyList()
        } else {
          this.showAlert(response.message, 'error')
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })
  }

  showAlert(text: string, type: 'success' | 'error') {
    this.toastr[type](text, 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }

}
