import { ChangeDetectorRef, Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { EmpGroupModel, MyEmpGroupModel } from 'src/app/shared/model/emp-group.model';
import { EmpGroupService } from 'src/app/shared/services/emp-group.service';
import { FileService } from 'src/app/shared/services/file.service';
export interface DataModel {
  groupId: string
  tdesc: string
  edesc: string
  companyId: string
  checked: boolean
}

@Component({
  selector: 'app-employee-group-unit',
  templateUrl: './employee-group-unit.component.html',
  styleUrls: ['./employee-group-unit.component.scss']
})
export class EmployeeGroupUnit implements OnInit {
  @Input() pathTitle = ['การจัดการข้อมูลองค์กร', 'ข้อมูลลักษณะงาน', 'กลุ่มพนักงาน']
  @Output() sendPathTitle: EventEmitter<string[]> = new EventEmitter<string[]>();
  activeTab: string = 'tab1'; // กำหนด tab เริ่มต้น

  // ฟังก์ชันในการเปลี่ยนแท็บ
  changeTab(tab: { id: string, text: string }) {
    this.sendPathTitle.emit(['การจัดการข้อมูลองค์กร', 'ข้อมูลลักษณะงาน', tab.text])
    this.activeTab = tab.id;
  }

  currentPage = 1
  selectedItems: string[] = [];
  modalStatus = 'add'
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  dataLoading = false
  dataSelect: DataModel = { groupId: "", tdesc: "", edesc: "", companyId: "", checked: false }
  emp_groupList: { check: boolean; data: DataModel & { checked?: boolean } }[] = []
  emp_group: EmpGroupModel = new MyEmpGroupModel({})
  search = ""
  selectedFile: File | null = null;
  selectedFileName: string = 'กรุณาเลือกไฟล์';

  constructor(private empGroupService: EmpGroupService,
    private toastr: ToastrService,
    private cdr: ChangeDetectorRef,
    private fileService: FileService
  ) { }

  ngOnInit(): void {
    this.getEmpGroupList()
  }

  onFileSelected(event: any) {
    this.selectedFile = event.target.files.length > 0 ? event.target.files[0] : null;
    this.selectedFileName = this.selectedFile?.name || "กรุณาเลือกไฟล์"
  }

  uploadFile() {
    if (!this.selectedFile) {
      alert('กรุณาเลือกไฟล์ก่อนอัปโหลด')
      return
    }
    const formData = new FormData();
    formData.append('file', this.selectedFile);
    this.fileService.upload(formData, 'mgroup').subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getEmpGroupList()
        } else {
          this.showAlert(response.message, 'error')
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })
  }

  downloadFile() {
    const fileName = 'IMPORT_MGROUP.xlsx'
    this.fileService.download(fileName).subscribe({
      next: response => {
        const url = window.URL.createObjectURL(response);
        const a = document.createElement("a");
        a.href = url;
        a.download = fileName;
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
        window.URL.revokeObjectURL(url);
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })

  }

  getEmpGroupList() {
    this.dataLoading = true
    this.empGroupService.getList().subscribe({
      next: response => {
        this.emp_groupList = response.map(x => ({ check: false, data: { groupId: x.groupId, tdesc: x.tdesc, edesc: x.edesc, companyId: x.companyId, checked: false } }))
        this.dataLoading = false
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.dataLoading = false
        console.error('Error fetching employee types:', error);
        this.cdr.detectChanges()
      }
    })
  }
  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.emp_groupListFilter().length / 10) }, (_, i) => i + 1);
  }
  emp_groupListFilter() {
    return this.emp_groupList.filter(x => {
      const data = x.data
      const match = data.groupId.toLowerCase().includes(this.search) || data.tdesc.toLowerCase().includes(this.search) || data.edesc.toLowerCase().includes(this.search);
      return match;
    });
  }
  setData(data?: DataModel) {
    this.dataSelect = JSON.parse(JSON.stringify(data || { groupId: "", tdesc: "", edesc: "", companyId: "" }));
  }

  addEmp_group() {
    const body = new MyEmpGroupModel({ groupId: this.dataSelect.groupId, tdesc: this.dataSelect.tdesc, edesc: this.dataSelect.edesc, companyId: this.dataSelect.companyId })
    this.empGroupService.post(body).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getEmpGroupList()
        } else {
          this.showAlert(response.message, 'error')
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })
  }
  deleteEmp_group() {
    let body: EmpGroupModel | EmpGroupModel[] = [];
  
    if (this.dataSelect.groupId) {
      body = new MyEmpGroupModel({groupId: this.dataSelect.groupId, tdesc: this.dataSelect.tdesc, edesc: this.dataSelect.edesc, companyId: this.dataSelect.companyId });
    } else {
      body = this.emp_groupList.filter(x => x.check).map(x => new MyEmpGroupModel({ groupId: x.data.groupId, tdesc: x.data.tdesc, edesc: x.data.edesc, companyId: x.data.companyId }));
    }
    this.empGroupService.delete(body).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success');
          this.getEmpGroupList();
        } else {
          this.showAlert(response.message, 'error');
        }
      },
      error: error => {
        this.showAlert(error.message, 'error')
      }
    });
  }
  

  toggleSelectAll(event: Event) {
    const checked = (event.target as HTMLInputElement).checked;

    this.emp_groupList.forEach(item => {
      item.check = checked;  // อัปเดตค่า check ใน emp_groupList
    });

    // อัปเดตรายการ selectedItems ด้วย groupId ของรายการที่ถูกเลือก
    this.selectedItems = checked ? this.emp_groupList.map(item => item.data.groupId) : [];

    this.cdr.detectChanges();  // แจ้ง Angular ให้รีเฟรช UI
  }


  showAlert(text: string, type: 'success' | 'error') {
    this.toastr[type](text, 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    })
  }
}
