import { ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { CompetencytopicModel, MyCompetencytopicModel } from 'src/app/shared/model/competencytopic.model';
import { CompetencytopicService } from 'src/app/shared/services/competencytopic.service';
export interface DataModel {
  code: string,
  name: string,
  type: string
}
@Component({
  selector: 'app-indicators-and-curriculum',
  templateUrl: './indicators-and-curriculum.component.html',
  styleUrls: ['./indicators-and-curriculum.component.scss']
})
export class IndicatorsAndCurriculumComponent {
  @Output() sendPathTitle: EventEmitter<string[]> = new EventEmitter<string[]>();
  editTab = false
  currentPage = 1
  search = ""
  page = Array.from({ length: 1 }, (_, i) => i + 1);

  dataList: DataModel[] = []
  indicatorsCoursesList: CompetencytopicModel[] = []
  indicatorsCourses: CompetencytopicModel = new MyCompetencytopicModel({})
  dataLoading = false
  constructor(private toastr: ToastrService,
    private cdr: ChangeDetectorRef,
    private competencytopicService: CompetencytopicService,
  ) {
    this.pathTitleChange()
  }
  ngOnInit(): void {
    this.getList()
  }
  getList() {
    this.dataLoading = true
    this.competencytopicService.getList().subscribe({
      next: response => {
        this.dataList = response.map(x => ({ code: x.competencyTopicId, name: x.tdesc, type: x.competencyType.tdesc }))
        this.indicatorsCoursesList = response
        this.dataLoading = false
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.dataLoading = false
        this.cdr.detectChanges()
      }
    })
  }
  selectIndicatorsCourses(data: DataModel) {
    const indicatorsCourses = this.indicatorsCoursesList.find(x => x.competencyTopicId == data.code)
    this.indicatorsCourses = new MyCompetencytopicModel(indicatorsCourses || {})
  }
  pathTitleChange() {
    this.sendPathTitle.emit(this.editTab ? ['การประเมินสมรรถนะ', 'การจัดการสมรรถนะ', 'ตัวชี้วัดเเละหลักสูตร', 'การจัดการตัวชี้วัดเเละหลักสูตร'] : ['การประเมินสมรรถนะ', 'การจัดการสมรรถนะ', 'ตัวชี้วัดเเละหลักสูตร'])
  }

  searchChange() {
    this.currentPage = 1;
    const filteredData = this.dataListFilter();
    this.page = Array.from({ length: Math.ceil(filteredData.length / 10) }, (_, i) => i + 1);
  }

  dataListFilter() {
    return this.dataList.filter(x => {
      const match = x.code.includes(this.search) || x.name.includes(this.search);
      return match;
    });
  }


  showSuccess() {
    this.toastr.success('บันทึกข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccessEdit() {
    this.toastr.success('เเก้ไขข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  showSuccessDelete() {
    this.toastr.success('ลบข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
  addUser() {
    console.log('เพิ่มผู้ใช้งาน');
  }

  deleteUser() {
    console.log('ลบผู้ใช้งาน');
  }

  editUser() {
    console.log('แก้ไขผู้ใช้งาน');
  }


}

