import { ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { MyCompetencycourseModel } from 'src/app/shared/model/competencycourse.model';
import { CompetencycourseService } from 'src/app/shared/services/competencycourse.service';
export interface DataModel {
  id: string
  name: string
  edesc: string
  detail: string
  topic: string
  checked: boolean
}
@Component({
  selector: 'app-development-course',
  templateUrl: './development-course.component.html',
  styleUrls: ['./development-course.component.scss']
})
export class DevelopmentCourseComponent {
  @Input() pathTitle = ['การประเมินสมรรถนะ', 'ทะเบียนหลักสูตร', 'หลักสูตรการพัฒนา'];
  @Output() sendPathTitle: EventEmitter<string[]> = new EventEmitter<string[]>();
  activeTab: string = 'tab1'; // กำหนด tab เริ่มต้น

  currentPage = 1
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  search = ""

  // ฟังก์ชันในการเปลี่ยนแท็บ
  changeTab(tab: { id: string, text: string }) {
    this.sendPathTitle.emit(['การประเมินสมรรถนะ', 'ตั้งค่าผู้ใช้งาน', tab.text]);
    this.activeTab = tab.id;
  }

  // การจัดการการเปิดปิด modal
  modalOptions: {
    [nameModal: string]: {
      isModalOpen: boolean;
      modalSize: string;
      backdropClose: boolean;
    };
  } = {
      "add": {
        isModalOpen: false,
        modalSize: 'm',
        backdropClose: true,
      },
      "edit": {
        isModalOpen: false,
        modalSize: 'm',
        backdropClose: true,
      }
    };

  openModal(name: string, size: string, closeOnBackdrop?: boolean) {
    this.modalOptions[name].modalSize = size;
    this.modalOptions[name].backdropClose = closeOnBackdrop || false;
    this.modalOptions[name].isModalOpen = true;
    this.currentModal = name;  // ตั้งค่าค่าของ currentModal เป็น 'add' หรือ 'edit'
    document.body.style.overflow = 'hidden';
  }

  closeModal(name: string) {
    this.modalOptions[name].isModalOpen = false;
    if (!this.isAnyModalOpen()) {
      document.body.style.overflow = ''; // คืนค่าการ Scroll เฉพาะเมื่อ Modal ทั้งหมดปิดแล้ว
    }
  }

  isAnyModalOpen(): boolean {
    return Object.values(this.modalOptions).some(modal => modal.isModalOpen); // ตรวจสอบว่า modal อื่นยังเปิดอยู่หรือไม่
  }

  // ฟังก์ชัน toggle checkbox
  isChecked: boolean = false; // ใช้สำหรับตรวจสอบสถานะของ checkbox

  toggleCheckbox() {
    this.isChecked = !this.isChecked;
    this.mockData.forEach((item) => {
      item.checked = this.isChecked;
    });
    this.checkSelect();
  }

  // ฟังก์ชันสำหรับการเพิ่ม ลบ หรือแก้ไข ข้อมูล
  addUser() {
    const body = new MyCompetencycourseModel({ competencyCourseId: this.dataSelect.id, tdesc: this.dataSelect.name, edesc: this.dataSelect.edesc, courseTopic: this.dataSelect.topic, courseDetail: this.dataSelect.detail })
    this.competencycourseService.post(body).subscribe((response: any) => {
      if (response.success) {
        this.showSuccess()
        this.getCompetencycourseList()
      }
    })
  }
  deleteUser() {
    const body = new MyCompetencycourseModel({ competencyCourseId: this.dataSelect.id, tdesc: this.dataSelect.name, edesc: this.dataSelect.edesc, courseTopic: this.dataSelect.topic, courseDetail: this.dataSelect.detail })
    this.competencycourseService.delete(body).subscribe((response: any) => {
      if (response.success) {
        this.showSuccessDelete()
        this.getCompetencycourseList()
      }
    })
  }

  currentModal = "";

  mockData: DataModel[] = []
  dataLoading = false
  dataSelect: DataModel = { id: "", name: "", edesc: "", topic: "", detail: "", checked: false }
  mockDataSelect: any = []


  constructor(private toastr: ToastrService,
    private cdr: ChangeDetectorRef,
    private competencycourseService: CompetencycourseService
  ) { }
  ngOnInit(): void {
    this.getCompetencycourseList()
  }
  getCompetencycourseList() {
    this.dataLoading = true
    this.competencycourseService.getList().subscribe({
      next: response => {
        this.mockData = response.map(x => ({ id: x.competencyCourseId, name: x.tdesc, edesc: x.edesc, topic: x.courseTopic, detail: x.courseDetail, checked: false }))
        this.dataLoading = false
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.dataLoading = false
        this.cdr.detectChanges()
      }
    })
  }
  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.dataListFilter().length / 10) }, (_, i) => i + 1);
  }
  dataListFilter() {
    return this.mockData.filter(x => {
      const data = x
      const match = data.id.includes(this.search) || data.name.includes(this.search)
      return match;
    });
  }
  selectCompetencycourse(data?: DataModel) {
    this.dataSelect = JSON.parse(JSON.stringify(data || { id: "", name: "", edesc: "", topic: "", detail: "", checked: false }));
  }

  checkSelect() {
    this.mockDataSelect = this.mockData.filter(item => item.checked);
  }
  showSuccess() {
    this.toastr.success('บันทึกข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }

  showSuccessEdit() {
    this.toastr.success('เเก้ไขข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }

  showSuccessDelete() {
    this.toastr.success('ลบข้อมูลสำเร็จ', 'เเจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
}
