import { ChangeDetectorRef, Component} from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { EvaluationCycleModel, MyEvaluationCycleModel } from 'src/app/shared/model/evaluation-cycle.model';
import { EvaluationCycleService } from 'src/app/shared/services/evaluation-cycle.service';
import { MyStatusCodeModel, StatusCodeModel } from 'src/app/shared/model/status-code.model';

export interface DataModel {
    evaluationRoundId: string;
    tdesc: string;
    edesc: string;
    apsyear: string;
    apsPeriodStart: string;
    apsPeriodEnd: string;
    statusCode: StatusCodeModel;
}

@Component({
    selector: 'app-evaluation-cycle',
    templateUrl: './evaluation-cycle.component.html',
    styleUrls: ['./evaluation-cycle.component.scss']
})
export class EvaluationCycleComponent {
  apsPeriodStart: string = '';
  apsPeriodEnd: string = ''; 

  currentPage = 1
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  search = ""
  modalStatus = 'add'
  evaluation_cyclelist: { check: boolean, data: DataModel }[] = []
  evaluation_cycle: EvaluationCycleModel = new MyEvaluationCycleModel({})
  dataLoading = false
  dataSelect: DataModel = { evaluationRoundId: "", tdesc: "", edesc: "", apsyear: "", apsPeriodStart: "", apsPeriodEnd: "", statusCode: new MyStatusCodeModel({})}
  itemToDelete: EvaluationCycleModel | null = null;
  isDataListChecked = false
  isDataListCheckedAll = false
  numDataListChecked = 0

  constructor(private evaluationCycleService: EvaluationCycleService,
    private toastr: ToastrService,
    private cdr: ChangeDetectorRef
  ) { }
  
  ngOnInit(): void {
    this.getEvaluationCycleList()
  }

  getEvaluationCycleList() {
    this.evaluationCycleService.getList().subscribe({
      next: response => {
        console.log('API response:', response);
        this.evaluation_cyclelist = response.map(x => ({
            check: false,
            data: {
                evaluationRoundId: x.evaluationRoundId,
                tdesc: x.tdesc,
                edesc: x.edesc,
                apsyear: x.apsyear,
                apsPeriodStart: x.apsPeriodStart,
                apsPeriodEnd: x.apsPeriodEnd,
                statusCode: new MyStatusCodeModel(x.statusCode || {})
            }
        }));
        this.searchChange();
        this.cdr.detectChanges();
      },
      error: err => {
        console.error('Error fetching evaluation cycles:', err);
      }
    });
  }
  dataListCheck() {
    const dataCheck = this.evaluation_cycleListFilter();
    this.isDataListChecked = dataCheck.some(x => x.check);
    this.isDataListCheckedAll = dataCheck.length ? dataCheck.every(x => x.check) : false;
    this.numDataListChecked = dataCheck.filter(x => x.check).length;
}
    
dataListCheckAll() {
    const selectAll = this.isDataListCheckedAll;
    this.evaluation_cyclelist.forEach(x => x.check = selectAll);
    this.dataListCheck();
}

  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.evaluation_cycleListFilter().length / 10) }, (_, i) => i + 1);
  }
  evaluation_cycleListFilter() {
    return this.evaluation_cyclelist.filter(x => {
      const data = x.data
      const match = data.evaluationRoundId.includes(this.search) || data.tdesc.includes(this.search) || data.edesc.includes(this.search);
      return match;
    });
  }
  setData(data?: DataModel) {
    this.dataSelect = JSON.parse(JSON.stringify(data || {
        evaluationRoundId: "",
        tdesc: "",
        edesc: "",
        apsyear: "",
        apsPeriodStart: "",
        apsPeriodEnd: "",
        statusCode: new MyStatusCodeModel({})
    }));
}
  addevaluation_cycle() {
    const body = new MyEvaluationCycleModel({ evaluationRoundId: this.dataSelect.evaluationRoundId, tdesc: this.dataSelect.tdesc, edesc: this.dataSelect.edesc, apsyear: this.dataSelect.apsyear, apsPeriodStart: this.dataSelect.apsPeriodStart, apsPeriodEnd: this.dataSelect.apsPeriodEnd, statusCode: this.dataSelect.statusCode })
    this.evaluationCycleService.post(body).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getEvaluationCycleList()
        } else {
          this.showAlert(response.message, 'error')
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })
  }

  deleteevaluation_cycle() {
    let body: EvaluationCycleModel | EvaluationCycleModel[] = []
    if (this.dataSelect.evaluationRoundId) {
      body = new MyEvaluationCycleModel({ evaluationRoundId: this.dataSelect.evaluationRoundId, tdesc: this.dataSelect.tdesc, edesc: this.dataSelect.edesc, apsyear: this.dataSelect.apsyear, apsPeriodStart: this.dataSelect.apsPeriodStart, apsPeriodEnd: this.dataSelect.apsPeriodEnd, statusCode: this.dataSelect.statusCode })
    } else {
      body = this.evaluation_cyclelist.filter(x => x.check).map(x => new MyEvaluationCycleModel({ evaluationRoundId: x.data.evaluationRoundId, tdesc: x.data.tdesc, edesc: x.data.edesc, apsyear: x.data.apsyear, apsPeriodStart: x.data.apsPeriodStart, apsPeriodEnd: x.data.apsPeriodEnd, statusCode: x.data.statusCode }))
    }
    this.evaluationCycleService.delete(body).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getEvaluationCycleList()
        } else {
          this.showAlert(response.message, 'error')
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })
  }

  showAlert(text: string, type: 'success' | 'error') {
    this.toastr[type](text, 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }
}


