import { ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { CompetencyGradeModel, MyCompetencyGradeModel } from 'src/app/shared/model/competency-grades.model';
import { MyCompetencyGroupGradeModel } from 'src/app/shared/model/competency-group-grade.model';
import { CompetencyGroupGradeService } from 'src/app/shared/services/competency-group-grade.service';

export interface DataModel {
  check: boolean
  code: string
  tdesc: string
  edesc: string
  competencyGrades: CompetencyGradeModel[]
}

@Component({
  selector: 'app-sub-grade-registration',
  templateUrl: './sub-grade-registration.component.html',
  styleUrls: ['./sub-grade-registration.component.scss'],
})
export class SubGradeRegistrationComponent {
  @Input() dataSelect: DataModel = { check: false, code: '', tdesc: '', edesc: '', competencyGrades: [] }
  @Output() sendDataSelect: EventEmitter<DataModel> = new EventEmitter<DataModel>();
  competencyGrade: { select: CompetencyGradeModel, dataList: { check: boolean, data: CompetencyGradeModel }[] } = { select: new MyCompetencyGradeModel({}), dataList: [] }
  currentPage = 1;
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  numDataListChecked = 0;
  isDataListCheckedAll = false;
  search = '';
  modalStatus: 'add' | 'edit' | 'delete' = 'add'
  constructor(private toastr: ToastrService,
    private competencyGroupGradeService: CompetencyGroupGradeService,
    private cdr: ChangeDetectorRef
  ) {
  }
  ngOnInit(): void {
    this.competencyGrade.dataList = this.dataSelect.competencyGrades.map(x => ({ check: false, data: x }))
    this.searchChange()
  }
  searchChange() {
    this.currentPage = 1;
    const filteredData = this.dataListFilter();
    this.page = Array.from({ length: Math.ceil(filteredData.length / 10) }, (_, i) => i + 1);
  }

  selectData(data?: { check: boolean, data: CompetencyGradeModel }) {
    this.competencyGrade.select = new MyCompetencyGradeModel(data?.data || {})
  }

  dataListFilter() {
    return this.competencyGrade.dataList.filter((x) => {
      const data = x.data
      const match = data.gradeId.toLowerCase().includes(this.search.toLowerCase()) || data.tdesc.toLowerCase().includes(this.search.toLowerCase()) || data.edesc.toLowerCase().includes(this.search.toLowerCase());
      if (!match) x.check = false;
      return match;
    });
  }

  dataListCheck() {
    const dataCheck = this.dataListFilter();
    this.isDataListCheckedAll = dataCheck.length ? dataCheck.every(x => x.check) : false;
    this.numDataListChecked = dataCheck.filter((x) => x.check).length;
  }

  dataListCheckAll() {
    this.isDataListCheckedAll = !this.isDataListCheckedAll;
    const selectAll = this.isDataListCheckedAll;
    this.competencyGrade.dataList = this.competencyGrade.dataList.filter((x) => {
      const data = x.data
      const match = data.gradeId.toLowerCase().includes(this.search.toLowerCase()) || data.tdesc.toLowerCase().includes(this.search.toLowerCase()) || data.edesc.toLowerCase().includes(this.search.toLowerCase());
      if (!match) x.check = false;
      return match;
    }).map(x => ({ ...x, check: selectAll }));
    this.dataListCheck();
  }
  updateCompetencyGroupGrade() {
    switch (this.modalStatus) {
      case 'add': {
        this.competencyGrade.dataList.push({ check: false, data: this.competencyGrade.select })
        this.cdr.detectChanges()
        break
      }
      case 'edit': {
        this.competencyGrade.dataList = this.competencyGrade.dataList.map(x => x.data.gradeId == this.competencyGrade.select.gradeId ? { check: false, data: this.competencyGrade.select } : x)
        this.cdr.detectChanges()
        break
      }
      case 'delete': {
        this.competencyGrade.dataList = this.competencyGrade.select.gradeId ? this.competencyGrade.dataList.filter(x => x.data.gradeId != this.competencyGrade.select.gradeId) : this.competencyGrade.dataList.filter(x => !x.check)
        this.cdr.detectChanges()
        break
      }
    }
    this.sendDataSelect.emit({ ...this.dataSelect, competencyGrades: this.competencyGrade.dataList.map(x => x.data) })
  }
  showAlert(text: string, type: 'success' | 'error') {
    this.toastr[type](text, 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    });
  }


}
