import { ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { ToastrService } from 'ngx-toastr';
import { MyCompetencytopicModel } from 'src/app/shared/model/competencytopic.model';
import { MyCompetencytypeModel } from 'src/app/shared/model/competencytype.model';
import { CompetencytopicService } from 'src/app/shared/services/competencytopic.service';
import { CompetencytypeService } from 'src/app/shared/services/competencytype.service';
import { FileService } from 'src/app/shared/services/file.service';
export interface DataModel {
  id: string
  name: string
  edesc: string
  code: string
  definition: string
  type: DataModel2
  checked: boolean
}
export interface DataModel2 {
  id: string
  name: string
  edesc: string
  code: string
  level: string
}
@Component({
  selector: 'app-competency-topic',
  templateUrl: './competency-topic.component.html',
  styleUrls: ['./competency-topic.component.scss']
})
export class CompetencyTopic {

  @Input() pathTitle = ['การประเมินสมรรถนะ', 'ทะเบียนกำหนดชื่อ', 'หัวข้อสมรรถนะ'];
  @Output() sendPathTitle: EventEmitter<string[]> = new EventEmitter<string[]>();
  activeTab: string = 'tab1'; // กำหนด tab เริ่มต้น

  // ฟังก์ชันในการเปลี่ยนแท็บ
  changeTab(tab: { id: string, text: string }) {
    this.sendPathTitle.emit(['การประเมินสมรรถนะ', 'ตั้งค่าผู้ใช้งาน', tab.text]);
    this.activeTab = tab.id;
  }

  currentPage = 1
  page = Array.from({ length: 1 }, (_, i) => i + 1);
  search = ""

  currentPageModal = 1
  pageModal = Array.from({ length: 1 }, (_, i) => i + 1);
  searchModal = ""

  isChecked: boolean = false; // ใช้สำหรับตรวจสอบสถานะของ checkbox
  currentModal = "";
  dataLoading = false
  dataSelectList: DataModel[] = [];
  dataSelect: DataModel = { id: "", name: "", edesc: "", code: "", definition: "", type: { id: "", name: "", edesc: "", code: "", level: "" }, checked: false }
  competencytypeListLoading = false
  competencytypeList: DataModel2[] = []
  competoncyTopicList: { check: boolean; data: DataModel & { checked?: boolean } }[] = []
  modalStatus = 'add'
  selectedFile: File | null = null;
  selectedFileName: string = 'กรุณาเลือกไฟล์';
  selectedItems: string[] = [];

  constructor(private toastr: ToastrService,
    private cdr: ChangeDetectorRef,
    private fileService: FileService,
    private competencytopicService: CompetencytopicService,
    private competencytypeService: CompetencytypeService
  ) { }
  ngOnInit(): void {
    this.getCompetencytopicList()
    this.getCompetencytypeList()
  }

  checkSelect() {
    this.dataSelectList = this.competoncyTopicList.filter(item => item.check).map(item => item.data);
  }

  toggleCheckbox() {
    this.isChecked = !this.isChecked; // สลับสถานะ'
    this.competoncyTopicList.forEach((item) => {
      item.check = this.isChecked;
    });
    this.checkSelect();
  }

  onFileSelected(event: any) {
    this.selectedFile = event.target.files.length > 0 ? event.target.files[0] : null;
    this.selectedFileName = this.selectedFile?.name || "กรุณาเลือกไฟล์"
  }

  uploadFile() {
    if (!this.selectedFile) {
      alert('กรุณาเลือกไฟล์ก่อนอัปโหลด')
      return
    }
    const formData = new FormData();
    formData.append('file', this.selectedFile);
    this.fileService.upload(formData, 'competency_topic').subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getCompetencytypeList()
          this.getCompetencytopicList()
        } else {
          this.showAlert(response.message, 'error')
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })
  }

  downloadFile() {
    const fileName = 'IMPORT_COMPETENCY_TOPIC.xlsx'
    this.fileService.download(fileName).subscribe({
      next: response => {
        const url = window.URL.createObjectURL(response);
        const a = document.createElement("a");
        a.href = url;
        a.download = fileName;
        document.body.appendChild(a);
        a.click();
        document.body.removeChild(a);
        window.URL.revokeObjectURL(url);
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })

  }

  getCompetencytypeList() {
    this.competencytypeListLoading = true
    this.competencytypeService.getList().subscribe({
      next: response => {
        this.competencytypeList = response.map(x => ({ id: x.competencyTypeId, name: x.tdesc, edesc: x.edesc, code: x.shortName, level: x.expectationLevel, checked: false }))
        this.competencytypeListLoading = false
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.competencytypeListLoading = false
        this.cdr.detectChanges()
      }
    })
  }
  searchCompetencytypeChange() {
    this.currentPageModal = 1
    this.pageModal = Array.from({ length: Math.ceil(this.competencytypeListFilter().length / 10) }, (_, i) => i + 1);
  }
  competencytypeListFilter() {
    return this.competencytypeList.filter(x => {
      const data = x
      const match = data.id.toLowerCase().includes(this.searchModal) || data.name.toLowerCase().includes(this.searchModal) || data.code.toLowerCase().includes(this.searchModal);
      return match;
    });
  }
  selectCompetencytype(data: DataModel2) {
    this.dataSelect.type = JSON.parse(JSON.stringify(data));
  }
  getCompetencytopicList() {
    this.dataLoading = true
    this.competencytopicService.getList().subscribe({
      next: response => {
        this.competoncyTopicList = response.map(x => ({
          check: false, data: {
            id: x.competencyTopicId, name: x.tdesc, edesc: x.edesc, code: x.competencyType.shortName, definition: x.competencyDetail,
            type: { id: x.competencyType.competencyTypeId, name: x.competencyType.tdesc, edesc: x.competencyType.edesc, code: x.competencyType.shortName, level: x.expectationLevel },
            checked: false
          }
        }))
        this.dataLoading = false
        this.searchChange()
        this.cdr.detectChanges()
      }, error: error => {
        this.dataLoading = false
        console.error('Error fetching employee types:', error);
        this.cdr.detectChanges()
      }
    })
  }
  searchChange() {
    this.currentPage = 1
    this.page = Array.from({ length: Math.ceil(this.dataListFilter().length / 10) }, (_, i) => i + 1);
  }
  dataListFilter() {
    return this.competoncyTopicList.filter(x => {
      const data = x.data
      const match = data.id.toLowerCase().includes(this.search) || data.name.toLowerCase().includes(this.search) || data.code.toLowerCase().includes(this.search);
      return match;
    });
  }
  setData(data?: DataModel) {
    this.dataSelect = JSON.parse(JSON.stringify(data || { id: "", name: "", edesc: "", code: "", definition: "", type: { id: "", name: "", edesc: "", code: "", level: "" }, checked: false }));
  }

  // ฟังก์ชันสำหรับการเพิ่ม ลบ หรือแก้ไข ข้อมูล
  addCompetency_topic() {
    const body = new MyCompetencytopicModel({
      competencyTopicId: this.dataSelect.id, tdesc: this.dataSelect.name, edesc: this.dataSelect.edesc, competencyDetail: this.dataSelect.definition,
      competencyType: new MyCompetencytypeModel({ competencyTypeId: this.dataSelect.type.id, tdesc: this.dataSelect.type.name, edesc: this.dataSelect.type.edesc, shortName: this.dataSelect.type.code, expectationLevel: this.dataSelect.type.level }),
    })
    this.competencytopicService.post(body).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getCompetencytypeList()
          this.getCompetencytopicList()
        } else {
          this.showAlert(response.message, 'error')
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })
  }
  deleteCompetency_topic() {
    let body: any
    if (this.modalStatus == "deleteGroup") {
      body = this.competoncyTopicList.filter(x => x.check).map(x => new MyCompetencytopicModel({
        competencyTopicId: x.data.id, tdesc: x.data.name, edesc: x.data.edesc, competencyDetail: x.data.definition,
        competencyType: new MyCompetencytypeModel({ competencyTypeId: x.data.type.id, tdesc: x.data.type.name, edesc: x.data.type.edesc, shortName: x.data.type.code, expectationLevel: x.data.type.level }),
      }))
    } else {
      body = new MyCompetencytopicModel({
        competencyTopicId: this.dataSelect.id, tdesc: this.dataSelect.name, edesc: this.dataSelect.edesc, competencyDetail: this.dataSelect.definition,
        competencyType: new MyCompetencytypeModel({ competencyTypeId: this.dataSelect.type.id, tdesc: this.dataSelect.type.name, edesc: this.dataSelect.type.edesc, shortName: this.dataSelect.type.code, expectationLevel: this.dataSelect.type.level }),
      })
    }
    console.log(body)
    this.competencytopicService.delete(body).subscribe({
      next: response => {
        if (response.success) {
          this.showAlert(response.message, 'success')
          this.getCompetencytypeList()
          this.getCompetencytopicList()
        } else {
          this.showAlert(response.message, 'error')
        }
      }, error: error => {
        this.showAlert(error.message, 'error')
      }
    })
  }

  showAlert(text: string, type: 'success' | 'error') {
    this.toastr[type](text, 'แจ้งเตือน', {
      timeOut: 3000,
      positionClass: 'toast-top-right',
    })
  }
}
